typedef enum {
    FORCE_DISPLAY_URGENCY_HINT_MS = 0,
    FLOATING_MAXIMUM_SIZE_HEIGHT = 1,
    FLOATING_MINIMUM_SIZE_HEIGHT = 2,
    BAR_STRIP_WORKSPACE_NUMBERS = 3,
    FLOATING_MAXIMUM_SIZE_WIDTH = 4,
    FLOATING_MINIMUM_SIZE_WIDTH = 5,
    BAR_BINDING_MODE_INDICATOR = 6,
    FOCUS_ON_WINDOW_ACTIVATION = 7,
    FORCE_DISPLAY_URGENCY_HINT = 8,
    BAR_STRIP_WORKSPACE_NAME = 9,
    DEFAULT_BORDER_PIXELS_PX = 10,
    WORKSPACE_BACK_AND_FORTH = 11,
    ASSIGN_WORKSPACE_NUMBER = 12,
    FLOATING_MAXIMUM_SIZE_X = 13,
    FLOATING_MINIMUM_SIZE_X = 14,
    POPUP_DURING_FULLSCREEN = 15,
    BAR_COLORS_IGNORE_LINE = 16,
    BAR_COLORS_BACKGROUND = 17,
    BAR_WORKSPACE_BUTTONS = 18,
    DEFAULT_BORDER_PIXELS = 19,
    WORKSPACE_OUTPUT_WORD = 20,
    BAR_SEPARATOR_SYMBOL = 21,
    FORCE_FOCUS_WRAPPING = 22,
    BAR_BINDSYM_COMMAND = 23,
    BAR_TRAY_PADDING_PX = 24,
    DEFAULT_ORIENTATION = 25,
    FOCUS_FOLLOWS_MOUSE = 26,
    BAR_STATUS_COMMAND = 27,
    BAR_WHEEL_DOWN_CMD = 28,
    COLOR_CHILD_BORDER = 29,
    FOR_WINDOW_COMMAND = 30,
    BAR_COLORS_BORDER = 31,
    BAR_COLORS_SINGLE = 32,
    FLOATING_MODIFIER = 33,
    HIDE_EDGE_BORDERS = 34,
    ASSIGN_WORKSPACE = 35,
    BAR_COLORS_BRACE = 36,
    BAR_HIDDEN_STATE = 37,
    BAR_TRAY_PADDING = 38,
    BAR_WHEEL_UP_CMD = 39,
    COLOR_BACKGROUND = 40,
    IPC_KILL_TIMEOUT = 41,
    MODE_BINDCOMMAND = 42,
    MODE_IGNORE_LINE = 43,
    WORKSPACE_LAYOUT = 44,
    WORKSPACE_OUTPUT = 45,
    BAR_BAR_COMMAND = 46,
    BAR_COLORS_TEXT = 47,
    BAR_IGNORE_LINE = 48,
    BAR_SOCKET_PATH = 49,
    BAR_TRAY_OUTPUT = 50,
    COLOR_INDICATOR = 51,
    DISABLE_RANDR15 = 52,
    DEFAULT_BORDER = 53,
    FOCUS_WRAPPING = 54,
    FORCE_XINERAMA = 55,
    ASSIGN_OUTPUT = 56,
    CRITERION_STR = 57,
    MOUSE_WARPING = 58,
    RESTART_STATE = 59,
    BAR_MODIFIER = 60,
    BAR_POSITION = 61,
    COLOR_BORDER = 62,
    COLOR_SINGLE = 63,
    FAKE_OUTPUTS = 64,
    MODE_BINDING = 65,
    NO_FOCUS_END = 66,
    BAR_BINDSYM = 67,
    BAR_VERBOSE = 68,
    BINDCOMMAND = 69,
    IGNORE_LINE = 70,
    TITLE_ALIGN = 71,
    BAR_COLORS = 72,
    BAR_OUTPUT = 73,
    COLOR_TEXT = 74,
    FOR_WINDOW = 75,
    IPC_SOCKET = 76,
    SHOW_MARKS = 77,
    CRITERION = 78,
    MODEBRACE = 79,
    WORKSPACE = 80,
    BARBRACE = 81,
    BAR_FONT = 82,
    BAR_MODE = 83,
    CRITERIA = 84,
    MODENAME = 85,
    NO_FOCUS = 86,
    BINDING = 87,
    INITIAL = 88,
    ASSIGN = 89,
    BAR_ID = 90,
    EXEC = 91,
    FONT = 92,
    MODE = 93,
    BAR = 94,
    __CALL = 95
} cmdp_state;
